@@ -200,6 +200,7 @@ def save(request, title):
 @URL('/+edit/<title:title>', methods=['GET'])
 def edit(request, title, preview=None, captcha_error=None):
     hatta.page.check_lock(request.wiki, title)
+    request.wiki.storage.reopen()
     exists = title in request.wiki.storage
     if exists:
         request.wiki.storage.reopen()
@@ -259,7 +260,7 @@ def download(request, title):
         mime = 'text/plain'
     data = request.wiki.storage.page_data(title)
     response = hatta.response.response(request, title, data,
-                             '/download', mime, size=-1)
+                             '/download', mime, size=len(data))
     response.direct_passthrough = True
     return response
 
@@ -576,7 +577,7 @@ def search(request):
     query = request.values.get('q', u'').strip()
     page = hatta.page.get_page(request, '')
     if not query:
-        url = request.get_url(view=request.wiki.all_pages, external=True)
+        url = request.get_url(view='all_pages', external=True)
         return werkzeug.routing.redirect(url, code=303)
     words = tuple(request.wiki.index.split_text(query))
     if not words:
